/****************************************************************************
** Meta object code from reading C++ file 'devicesmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.0/kcms/libkwindevices/devicesmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'devicesmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KWinDevices12DevicesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KWinDevices::DevicesModel::qt_create_metaobjectdata<qt_meta_tag_ZN11KWinDevices12DevicesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWinDevices::DevicesModel",
        "needsSaveChanged",
        "",
        "deviceRemoved",
        "sysName",
        "onDeviceAdded",
        "onDeviceRemoved",
        "deviceAt",
        "InputDevice*",
        "row",
        "Roles",
        "DeviceRole",
        "SysNameRole",
        "Kind",
        "Pointers",
        "Keyboards",
        "Touch"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needsSaveChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'onDeviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'deviceAt'
        QtMocHelpers::MethodData<InputDevice *(int) const>(7, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 8, {{
            { QMetaType::Int, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(10, 10, QMC::EnumFlags{}).add({
            {   11, Roles::DeviceRole },
            {   12, Roles::SysNameRole },
        }),
        // enum 'Kind'
        QtMocHelpers::EnumData<enum Kind>(13, 13, QMC::EnumIsScoped).add({
            {   14, Kind::Pointers },
            {   15, Kind::Keyboards },
            {   16, Kind::Touch },
        }),
    };
    return QtMocHelpers::metaObjectData<DevicesModel, qt_meta_tag_ZN11KWinDevices12DevicesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWinDevices::DevicesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KWinDevices12DevicesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KWinDevices12DevicesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KWinDevices12DevicesModelE_t>.metaTypes,
    nullptr
} };

void KWinDevices::DevicesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DevicesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needsSaveChanged(); break;
        case 1: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->onDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: { InputDevice* _r = _t->deviceAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<InputDevice**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DevicesModel::*)()>(_a, &DevicesModel::needsSaveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DevicesModel::*)(const QString & )>(_a, &DevicesModel::deviceRemoved, 1))
            return;
    }
}

const QMetaObject *KWinDevices::DevicesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWinDevices::DevicesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KWinDevices12DevicesModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KWinDevices::DevicesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KWinDevices::DevicesModel::needsSaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWinDevices::DevicesModel::deviceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
