/****************************************************************************
** Meta object code from reading C++ file 'activityconfig.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.0/kcms/activities/activityconfig.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'activityconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ActivityConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto ActivityConfig::qt_create_metaobjectdata<qt_meta_tag_ZN14ActivityConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActivityConfig",
        "activityIdChanged",
        "",
        "infoChanged",
        "save",
        "activityId",
        "name",
        "description",
        "iconName",
        "isPrivate",
        "shortcut",
        "QKeySequence",
        "isSaveNeeded",
        "inhibitScreen",
        "inhibitSleep"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activityIdChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'infoChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'activityId'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'isPrivate'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'shortcut'
        QtMocHelpers::PropertyData<QKeySequence>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'isSaveNeeded'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'inhibitScreen'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'inhibitSleep'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ActivityConfig, qt_meta_tag_ZN14ActivityConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ActivityConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ActivityConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ActivityConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ActivityConfigE_t>.metaTypes,
    nullptr
} };

void ActivityConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActivityConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activityIdChanged(); break;
        case 1: _t->infoChanged(); break;
        case 2: _t->save(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActivityConfig::*)()>(_a, &ActivityConfig::activityIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivityConfig::*)()>(_a, &ActivityConfig::infoChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->activityId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_name; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_description; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_iconName; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_private; break;
        case 5: *reinterpret_cast<QKeySequence*>(_v) = _t->m_shortcut; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isSaveNeeded(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->m_inhibitScreen; break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->m_inhibitSleep; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActivityId(*reinterpret_cast<QString*>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_name, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->infoChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_description, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->infoChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_iconName, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->infoChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_private, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->infoChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_shortcut, *reinterpret_cast<QKeySequence*>(_v)))
                Q_EMIT _t->infoChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_inhibitScreen, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->infoChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_inhibitSleep, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->infoChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *ActivityConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActivityConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ActivityConfigE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ActivityConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ActivityConfig::activityIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ActivityConfig::infoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
